Crate opencodecommit

Crate opencodecommit 

Modules

api
backend
config
context
dispatch
git
languages
Default language definitions and all prompt text.
prompt
response
scan
sensitive

Enums

Error
Crate-level error type.

Statics

TEST_CWD_LOCK

Functions

generate_and_commit
Generate a commit message and execute git commit.
generate_and_create_branch
Generate a branch name and create+checkout the branch.
generate_branch_name
Generate a branch name from the current repo state.
generate_commit_message
Generate a commit message from the current git repo state.
refine_commit_message
Refine an existing commit message based on user feedback.

Type Aliases

Result