pub fn format_commit_message(parsed: &ParsedCommit, config: &Config) -> StringExpand description
Format a parsed commit using the config template, emojis, lowercase.
pub fn format_commit_message(parsed: &ParsedCommit, config: &Config) -> StringFormat a parsed commit using the config template, emojis, lowercase.