Modules
- backend
- config
- context
- git
- languages
- Default language definitions and all prompt text.
- prompt
- response
- sensitive
Enums
- Error
- Crate-level error type.
Statics
Functions
- generate_
and_ commit - Generate a commit message and execute git commit.
- generate_
and_ create_ branch - Generate a branch name and create+checkout the branch.
- generate_
branch_ name - Generate a branch name from the current repo state.
- generate_
commit_ message - Generate a commit message from the current git repo state.
- refine_
commit_ message - Refine an existing commit message based on user feedback.