Crate opencodecommit

Crate opencodecommit 

Modules

backend
config
context
git
prompt
response

Enums

Error
Crate-level error type.

Functions

generate_commit_message
Generate a commit message from the current git repo state.
refine_commit_message
Refine an existing commit message based on user feedback.

Type Aliases

Result